"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * An ESLint rule to ban index signatures, which are notoriously unsound.
 */
const noIndexSignature = {
    meta: {
        type: "problem",
        docs: {
            category: "Possible Errors",
            description: "Bans index signatures.",
            recommended: "error",
            url: "https://github.com/danielnixon/eslint-plugin-total-functions",
        },
        messages: {
            errorStringGeneric: "Index signatures are unsound. Use an immutable Map such as that provided by immutable.js instead.",
        },
        schema: [],
    },
    create: (context) => {
        return {
            TSIndexedAccessType: (node) => {
                // eslint-disable-next-line functional/no-expression-statement
                context.report({
                    node: node,
                    messageId: "errorStringGeneric",
                });
            },
        };
    },
};
exports.default = noIndexSignature;
