"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// TODO https://github.com/typescript-eslint/typescript-eslint/pull/2601
/* eslint-disable total-functions/no-unsafe-mutable-readonly-assignment */
const no_unsafe_optional_property_assignment_1 = __importDefault(require("./no-unsafe-optional-property-assignment"));
const ts_eslint_1 = require("@typescript-eslint/experimental-utils/dist/ts-eslint");
const ts_estree_1 = require("@typescript-eslint/experimental-utils/dist/ts-estree");
const ruleTester = new ts_eslint_1.RuleTester({
    parserOptions: {
        sourceType: "module",
        project: "./tsconfig.tests.json",
    },
    parser: require.resolve("@typescript-eslint/parser"),
});
// eslint-disable-next-line functional/no-expression-statement
ruleTester.run("no-unsafe-optional-property-assignment", no_unsafe_optional_property_assignment_1.default, {
    valid: [
        {
            filename: "file.ts",
            code: `
        type Foo = { readonly foo: string };
        type Bar = { readonly foo: string; readonly bar: (() => unknown) | undefined };
        const thing = { foo: "foo", bar: "bar" };
        const foo: Foo = thing;
        const bar: Bar = { ...foo, bar: undefined };
      `,
        },
    ],
    invalid: [
        {
            filename: "file.ts",
            code: `
        type Foo = { readonly foo: string };
        type Bar = { readonly foo: string; readonly bar?: () => unknown };
        const thing = { foo: "foo", bar: "bar" };
        const foo: Foo = thing;
        const bar: Bar = foo;
      `,
            errors: [
                {
                    messageId: "errorStringVariableDeclaration",
                    type: ts_estree_1.AST_NODE_TYPES.VariableDeclaration,
                },
            ],
        },
        {
            filename: "file.ts",
            code: `
        type Foo = { readonly foo: string };
        type Bar = Foo & { readonly bar?: () => unknown };
        const thing = { foo: "foo", bar: "bar" };
        const foo: Foo = thing;
        const bar: Bar = foo;
      `,
            errors: [
                {
                    messageId: "errorStringVariableDeclaration",
                    type: ts_estree_1.AST_NODE_TYPES.VariableDeclaration,
                },
            ],
        },
    ],
});
